@@ -6,8 +6,10 @@ http://pypi.python.org/pypi/blessed
 # std imports
 import platform as _platform
 
-# local
-from blessed.terminal import Terminal
+if _platform.system() == 'Windows':
+    from blessed.win_terminal import Terminal
+else:
+    from blessed.terminal import Terminal
 
 if ('3', '0', '0') <= _platform.python_version_tuple() < ('3', '2', '2+'):
     # Good till 3.2.10
@@ -16,4 +18,4 @@ if ('3', '0', '0') <= _platform.python_version_tuple() < ('3', '2', '2+'):
                       'support due to http://bugs.python.org/issue10570.')
 
 __all__ = ('Terminal',)
-__version__ = '1.15.0'
+__version__ = '1.17.4'
